<img src="https://bytebucket.org/artegorov/svist4get/raw/3c65c3c6c42a0fac299d0ade1925de013251d8e6/docs/logo_128.png" />

svist4get is a simple bioinformatics tool for visualization of genomic signal tracks in user-defined genomic windows, either arbitrary selected by genomic coordinates or anchored to particular transcripts or genes.




**The detailed documentation is available at [Home Page](https://bitbucket.org/artegorov/svist4get/)**
